<TS language="gl" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Acerca de Gridcoin</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Crear unha nova dirección</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiar a dirección seleccionada ao cartafol</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Amosar &amp;QR Code</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Firma a mensaxe para probar que tes unha dirección Gridcoin</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Firmar &amp;Mensaxe</translation>
    </message>
    <message>
        <source>Verify a message to ensure it was signed with a specified Gridcoin address</source>
        <translation>Verifica a mensaxe para asegurar que foi asinada por unha concreta dirección de Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar Mensaxe.</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Borrar a dirección actualmente seleccionada da listaxe</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Libreta de direccións</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Estas son as túas dIreccións de Gridcoin para recibir os pagos. Pode que quieras asignarlle unha a cada remitente e así reconocer quen te está a pagar.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copiar &amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Modificar</translation>
    </message>
    <message>
        <source>Export Address Book Data</source>
        <translation>Exportar datos da libreta de direccións.</translation>
    </message>
    <message>
        <source>Error exporting</source>
        <translation>Error exportando</translation>
    </message>
    <message>
        <source>Could not write to file %1.</source>
        <translation>Non se puido escribir a arquivo %1</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sen etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diálogo de Contrasinal</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Introduce contrasinal</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Novo contrasinal</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repite novo contrasinal</translation>
    </message>
    <message>
        <source>For staking only</source>
        <translation>Para "staking" só</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Encriptar moedeiro</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operación precisa o contrasinal do teu moedeiro para desbloquear o moedeiro.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear moedeiro</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambiar contrasinal</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Introduce o vello e novo contrasinais no moedeiro.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirmar encriptación de moedeiro</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR COINS&lt;/b&gt;!</source>
        <translation>Coidado: Se enctriptas a tua carteira e perdes o contrasinal, &lt;b&gt;PERDERÁS TODAS AS TÚAS MOEDAS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Estás seguro de que desexas encriptar o teu moedeiro?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Moedeiro encriptado</translation>
    </message>
    <message>
        <source>Gridcoin will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your coins from being stolen by malware infecting your computer.</source>
        <translation>Gridcoin pecharase agora para rematar o proceso de encriptación. Recorda que encriptar a túa carteira non te protexe na totalidade do roubo das tuas moedas por infeccións de malware no teu ordenador.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANTE: Calquera copia de seguridade previa que fixeses do teu arquivo de moedeiro debería ser substituída polo recén xerado arquivo encriptado de moedeiro. Por razóns de seguridade, as copias de seguridade previas de un arquivo de moedeiro desencriptado tornaránse inútiles no momento no que comeces a emprega-lo novo, encriptado, moedeiro.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Encriptación de moedeiro fallida</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>A encriptación do moedeiro fallou por mor dun erro interno. O teu moedeiro non foi encriptado.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Os contrasinais suministrados non coinciden.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Desbloqueo de moedeiro fallido</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>O contrasinal introducido para a desencriptación do moedeiro foi incorrecto.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Cambiouse con éxito o contrasinal do moedeiro.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Precaución: A tecla de Bloqueo de Maiúsculas está activada!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Moedeiro</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Vista xeral</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Amosar vista xeral do moedeiro</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>Send coins to a Gridcoin address</source>
        <translation>Enviar moedas a unha dirección Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Recibir</translation>
    </message>
    <message>
        <source>Show the list of addresses for receiving payments</source>
        <translation>Amosa a lista de dirección para recibir os pagos</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Navegar historial de transaccións</translation>
    </message>
    <message>
        <source>Edit the list of stored addresses and labels</source>
        <translation>Edita a lista de direccións e etiquetas almaceadas</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Saír</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Saír da aplicación</translation>
    </message>
    <message>
        <source>&amp;About Gridcoin</source>
        <translation>&amp;Sobre Gridcoin</translation>
    </message>
    <message>
        <source>Show information about Gridcoin</source>
        <translation>Amosa información sobre Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opcións...</translation>
    </message>
    <message>
        <source>Modify configuration options for Gridcoin</source>
        <translation>Modificar opcións de configuración para Gridcoin</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Amosar/Agachar</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Encriptar Moedeiro...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Cambiar contrasinal...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Cambiar o contrasinal empregado para a encriptación do moedeiro</translation>
    </message>
    <message>
        <source>&amp;Unlock Wallet...</source>
        <translation>&amp;Desbloquear Carteira...</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear carteira</translation>
    </message>
    <message>
        <source>&amp;Lock Wallet</source>
        <translation>&amp;Bloquear Carteira</translation>
    </message>
    <message>
        <source>Lock wallet</source>
        <translation>Bloquear carteira</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;Asinar mensaxe...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verificar mensaxe...</translation>
    </message>
    <message>
        <source>&amp;Export...</source>
        <translation>&amp;Exportar...</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar datos da pestana actual a un arquivo</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>Ventana de &amp;Depuración</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Abrir consola de depuración e diagnóstico</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Axus&amp;tes</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;xuda</translation>
    </message>
    <message>
        <source>Gridcoin client</source>
        <translation>Cliente Gridcoin</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Actualizado</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Poñendo ao día...</translation>
    </message>
    <message>
        <source>Last received block was generated %1.</source>
        <translation>Último bloque recibido foi generado %1.</translation>
    </message>
    <message>
        <source>Confirm transaction fee</source>
        <translation>Confirmar cuota da transacción</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Transacción enviada</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transacción entrante</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>O moedeiro está &lt;b&gt;encriptado&lt;/b&gt; e actualmente &lt;b&gt;bloqueado&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Alerta de Rede</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Cantidade:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Importe:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Pago:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Cambiar:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidade</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Confirmacións</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar dirección</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar ID de transacción</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar pago</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar despóis do pago</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar cambio</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <source>no</source>
        <translation>non</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sen etiqueta)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(cambio)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Modificar Dirección</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Dirección</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Nova dirección para recibir</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nova dirección para enviar</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Modificar dirección para recibir</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Modificar dirección para enviar</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>A dirección introducida "%1" xa está no libro de direccións.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Non se puido desbloquear o moedeiro.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>A xeración de nova clave fallou.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcións</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Principal</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Rede</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Mapear porto empregando &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Porto:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Porto do proxy (exemplo: 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Minimizar en lugar de saír da aplicación cando se pecha a xanela. Cando se habilita esta opción, a aplicación so se pechará tras seleccionar Saír no menú.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>&amp;Visualizar direccións na listaxe de transaccións</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Xanela</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Amosar so un icono na bandexa tras minimiza-la xanela.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimizar á bandexa en lugar de á barra de tarefas.</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimizar ao pechar</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Visualización</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>&amp;Linguaxe de interface de usuario:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Unidade na que amosar as cantidades:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Escolle a unidade de subdivisión por defecto para amosar na interface e ao enviar moedas.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>default</source>
        <translation>por defecto</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>A dirección de proxy suministrada é inválida.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formulario</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>O teu balance actualmente dispoñible</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Inmaduro:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>O teu balance actual total</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Versión do cliente</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Información</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Tempo de arranque</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Número de conexións</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Cadea de bloques</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Número actual de bloques</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Hora do último bloque</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Consola</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation>&amp;Tráfico de Rede</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>Totais</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>Dentro:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Fóra:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Arquivo de log de depuración</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Limpar consola</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Bloques totais estimados</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Nome do cliente</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Emprega as flechas arriba e abaixo para navegar polo historial, e &lt;b&gt;Ctrl-L&lt;/b&gt; para limpar a pantalla.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Escribe &lt;b&gt;axuda&lt;/b&gt; para unha vista xeral dos comandos dispoñibles.</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Moedas Enviadas</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fondos insuficientes</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Cantidade:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Importe:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Pago:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Enviar a múltiples receptores á vez</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Engadir &amp;Receptor</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpar &amp;Todo</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Confirmar a acción de envío</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;Enviar</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Copiar pago</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Copiar despóis do pago</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Copiar bytes</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Copiar cambio</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Confirmar envío de moedas</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>A dirección de recepción non é válida, por favor compróbea.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>A cantidade a pagar debe ser maior que 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>A cantidade sobrepasa o teu balance.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>O total sobrepasa o teu balance cando se inclúe a tarifa de transacción %1.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Atopouse dirección duplicada, so se pode enviar a cada dirección unha vez por operación.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sen etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Cantidade:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Pagar &amp;A:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Mensaxe:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiqueta:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección dende portapapeis</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Introduce unha etiqueta para esta dirección para engadila ao teu libro de direccións</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Sinaturas - Asinar / Verificar unha Mensaxe</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Asinar Mensaxe</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Podes asinar mensaxes coas túas direccións para probar que ti as posees. Ten conta de non asinar nada vago, xa que hai ataques de phishing que tentarán que asines coa túa identidade por riba deles. Asina únicamente declaracións totalmente detalladas coas que esteas de acordo.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Pegar dirección dende portapapeis</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Introduce a mensaxe que queres asinar aquí</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Copiar a sinatura actual ao portapapeis do sistema</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Asinar &amp;Mensaxe</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Restaurar todos os campos de sinatura de mensaxe</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Limpar &amp;Todo</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verificar Mensaxe</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Introduce a dirección coa que asinar, a mensaxe (asegúrate de copiar exactamente os saltos de liña, espacios, tabulacións, etc.) e a sinatura debaixo para verificar a mensaxe. Ten coidado de non ler máis na sinatura do que hai no mensaxe asinado mesmo, a fin de evitar ser cazado nun ataque de home no medio.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Restaurar todos os campos de verificación de mensaxe</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Click en "Asinar Mensaxe" para xerar sinatura</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>A dirección introducida é inválida.</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Por favor comproba a dirección e proba de novo.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>A dirección introducida non se refire a ninguna clave.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Cancelouse o desbloqueo do moedeiro.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>A clave privada da dirección introducida non está dispoñible.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Fallou a sinatura da mensaxe.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Mensaxe asinada.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>A sinatura non puido ser decodificada.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Por favor revise a sinatura e probe de novo.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>A sinatura non coincide co resumo da mensaxe.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>A verificación da mensaxe fallou.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Mensaxe verificada.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Aberto ata %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/fóra de liña</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/sen confirmar</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 confirmacións</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, non foi propagado con éxito todavía</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Orixe</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Dende</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>descoñecido</translation>
    </message>
    <message>
        <source>To</source>
        <translation>A</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>dirección propia</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiqueta</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Crédito</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>non aceptado</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Débito</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Tarifa de transacción</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Cantidade neta</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Mensaxe</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidade</translation>
    </message>
    <message>
        <source>true</source>
        <translation>verdadeiro</translation>
    </message>
    <message>
        <source>false</source>
        <translation>falso</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Detalles de transacción</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Este panel amosa unha descripción detallada da transacción</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidade</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Aberto ata %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Confirmado (%1 confirmacións)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Xerado pero non aceptado</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recibido con</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Recibido de</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado a</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pago a ti mesmo</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Estado da transacción. Pasa por riba deste campo para amosar o número de confirmacións.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Data e hora na que foi recibida a transacción.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipo de transacción.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Dirección de destino da transacción.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Cantidade borrada ou engadida no balance.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Hoxe</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Esta semana</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Este mes</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>O último mes</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Este ano</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Periodo...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Recibido con</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Enviado a</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>A ti mesmo</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minado</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Outro</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Cantidade mínima</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Copiar dirección</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Copiar etiqueta</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Copiar cantidade</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Copiar ID de transacción</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Modificar etiqueta</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Amosar detalles da transacción</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Confirmado</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Cantidade</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Periodo:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>a</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>Ocorreu un erro mentres se establecía o porto RPC %u para escoitar sobre IPv6, voltando a IPv4: %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>Ocorreu un erro mentres se establecía o porto RPC %u para escoitar sobre IPv4: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Emprego:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Listar comandos</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Obter axuda para un comando</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Precaución: -paytxfee está posto moi algo! Esta é a tarifa de transacción que ti pagarás se envías unha transacción.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Precaución: wallet.dat corrupto, datos salvagardados! O wallet.dat orixinal foi gardado como wallet.{timestamp}.bak en %s; se o teu balance ou transaccións son incorrectas deberías restauralas dende unha copia de seguridade.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Precaución: erro lendo wallet.dat! Tódalas claves lidas correctamente, pero os datos de transacción ou as entradas do libro de direccións podrían estar ausentes ou incorrectos.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Fallou escoitar en calquera porto. Emprega -listen=0 se queres esto.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>Empregar a opción %s</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>Debes fixar rpcpassword=&lt;contrasinal&gt; no arquivo de configuración:
%s
Se o arquivo non existe, debes crealo con permisos de so lectura para o propietario.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>Cantidade inválida para -paytxfee=&lt;cantidade&gt;: '%s'</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat corrupto, fallou o gardado</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Dirección -proxy inválida: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Non se pode resolver a dirección -bind: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Non se pode resolver dirección -externalip: '%s'</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Erro cargando wallet.dat: Moedeiro corrupto</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Erro cargando wallet.dat</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Cargando direccións...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Imposible enlazar con %s neste ordenador (enlace devolveu erro %d, %s)</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Cantidade inválida</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Rede descoñecida especificada en -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Fondos insuficientes</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Cargando índice de bloques...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Cargando moedeiro...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Non se pode escribir a dirección por defecto</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Rescaneando...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Carga completa</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
</TS>